@@ -1,24 +1,10 @@
 #' @export
 as.data.frame.metamer_list <- function(x, ..., n = length(x)) {
-  x <- trim(x, n = n)
-  n <- nrow(x[[1]])
-  df <- do.call(rbind, x)
-  df$.metamer <- rep(1:length(x), each = n)
-  df$.name <- rep(attr(x, "name"), each = n)
-  lc <- length(colnames(df))
-  df <- df[, c(lc, 1:(lc-1))]
-  return(df)
+  return(x$as.data.frame())
 }
 
 
 
-
-#' @export
-print.metamer_list <- function(x, ...) {
-  cat("List of ", length(x), " metamers", sep = "")
-}
-
-
 # Dynamically exported. From:
 # https://community.rstudio.com/t/write-s3-methods-for-generics-from-other-packages-without-importing-that-package/8884/4
 fortify.metamer_list <- function(model, data, ..., n = 6) {
@@ -29,8 +15,7 @@ as.data.table.metamer_list <- function(x, ..., n = length(x)) {
   if (!requireNamespace("data.table", quietly = TRUE)) {
     stop("data.table is not installed. Install it with `install.packages(\"data.table\")`.")
   }
-  x <- trim(x, n = n)
-  data.table::rbindlist(x, idcol = ".metamer")
+  return(x$as.data.table())
 }
 
 
